diff --git a/core/pom.xml b/core/pom.xml
index a20578f5d7..ba280fb1d4 100644
--- a/core/pom.xml
+++ b/core/pom.xml
@@ -110,7 +110,7 @@
com.google.guava
guava
- r08
+ r09
com.google.code.findbugs
diff --git a/core/src/main/java/org/jclouds/concurrent/Futures.java b/core/src/main/java/org/jclouds/concurrent/Futures.java
index c36ad7856b..61f4b06490 100644
--- a/core/src/main/java/org/jclouds/concurrent/Futures.java
+++ b/core/src/main/java/org/jclouds/concurrent/Futures.java
@@ -264,11 +264,11 @@ public class Futures {
return Futures.LazyListenableFutureFunctionAdapter.create(
((org.jclouds.concurrent.Futures.ListenableFutureAdapter) future).futureListener, function);
else
- return com.google.common.util.concurrent.Futures.compose(lf, function, executorService);
+ return com.google.common.util.concurrent.Futures.transform(lf, function, executorService);
} else if (executorService.getClass().isAnnotationPresent(SingleThreaded.class)) {
return Futures.LazyListenableFutureFunctionAdapter.create(future, function, executorService);
} else {
- return com.google.common.util.concurrent.Futures.compose(Futures.makeListenable(future, executorService),
+ return com.google.common.util.concurrent.Futures.transform(Futures.makeListenable(future, executorService),
function, executorService);
}
}
diff --git a/core/src/main/java/org/jclouds/concurrent/config/ExecutorServiceModule.java b/core/src/main/java/org/jclouds/concurrent/config/ExecutorServiceModule.java
index 24ef2a8690..27ac1702e3 100644
--- a/core/src/main/java/org/jclouds/concurrent/config/ExecutorServiceModule.java
+++ b/core/src/main/java/org/jclouds/concurrent/config/ExecutorServiceModule.java
@@ -178,7 +178,7 @@ public class ExecutorServiceModule extends AbstractModule {
return new AddToStringFuture(delegate.submit(task), task.toString());
}
- @SuppressWarnings("unchecked")
+ @SuppressWarnings({ "unchecked", "rawtypes" })
@Override
public Future> submit(Runnable task) {
return new AddToStringFuture(delegate.submit(task), task.toString());
diff --git a/core/src/main/java/org/jclouds/util/Utils.java b/core/src/main/java/org/jclouds/util/Utils.java
index 1d4a95d946..f669e79091 100644
--- a/core/src/main/java/org/jclouds/util/Utils.java
+++ b/core/src/main/java/org/jclouds/util/Utils.java
@@ -242,7 +242,7 @@ public class Utils {
@SuppressWarnings("unchecked")
@Deprecated
public static Iterable getSupportedProvidersOfTypeInProperties(
- final Class extends RestContextBuilder> type, final Properties properties) {
+ final Class extends RestContextBuilder,?>> type, final Properties properties) {
return Providers.getSupportedProvidersOfTypeInProperties(type, properties);
}
diff --git a/scriptbuilder/pom.xml b/scriptbuilder/pom.xml
index 3d114afe12..11110c8835 100644
--- a/scriptbuilder/pom.xml
+++ b/scriptbuilder/pom.xml
@@ -39,7 +39,7 @@
com.google.guava
guava
- r08
+ r09
com.google.code.findbugs
diff --git a/core/src/test/java/com/google/common/util/concurrent/FuturesComposePerformanceTest.java b/core/src/test/java/com/google/common/util/concurrent/FuturesTransformPerformanceTest.java
similarity index 89%
rename from core/src/test/java/com/google/common/util/concurrent/FuturesComposePerformanceTest.java
rename to core/src/test/java/com/google/common/util/concurrent/FuturesTransformPerformanceTest.java
index 0cf4b24755..e436beca97 100644
--- a/core/src/test/java/com/google/common/util/concurrent/FuturesComposePerformanceTest.java
+++ b/core/src/test/java/com/google/common/util/concurrent/FuturesTransformPerformanceTest.java
@@ -53,23 +53,23 @@ import com.google.common.collect.Sets;
* {@code LISTENER_DURATION} is the time that the attached listener or function
*
*
- * The execution time of a composed task within a composite should not be more than {@code
+ * The execution time of a transformd task within a composite should not be more than {@code
* IO_DURATION} + {@code LISTENER_DURATION} + overhead when a threadpool is used. This is because
* the listener should be invoked as soon as the result is available.
*
- * The execution time of a composed task within a composite should not be more than {@code
+ * The execution time of a transformd task within a composite should not be more than {@code
* IO_DURATION} + {@code LISTENER_DURATION} * {@code COUNT} + overhead when caller thread is used
* for handling the listeners.
*
* This test shows that Futures.compose eagerly issues a get() on the source future. code iterating
* over futures and assigning listeners will take the same amount of time as calling get() on each
* one, if using a within thread executor. This exposes an inefficiency which can make some use
* cases in google appengine impossible to achieve within the cutoff limits.
*
* @author Adrian Cole
*/
-@Test(groups = "performance", enabled = false, sequential = true, testName = "FuturesComposePerformanceTest")
-public class FuturesComposePerformanceTest {
+@Test(groups = "performance", enabled = false, sequential = true, testName = "FuturesTransformPerformanceTest")
+public class FuturesTransformPerformanceTest {
private static final int FUDGE = 5;
private static final int COUNT = 100;
private static final int IO_DURATION = 50;
@@ -93,7 +93,7 @@ public class FuturesComposePerformanceTest {
ExecutorService chainExecutor = userthreads;
ExecutorService listenerExecutor = userthreads;
- checkThresholdsUsingFuturesCompose(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
+ checkThresholdsUsingFuturesTransform(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
} finally {
userthreads.shutdownNow();
}
@@ -115,7 +115,7 @@ public class FuturesComposePerformanceTest {
ExecutorService chainExecutor = userthreads;
ExecutorService listenerExecutor = MoreExecutors.sameThreadExecutor();
- checkThresholdsUsingFuturesCompose(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
+ checkThresholdsUsingFuturesTransform(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
} finally {
userthreads.shutdownNow();
}
@@ -139,7 +139,7 @@ public class FuturesComposePerformanceTest {
ExecutorService chainExecutor = MoreExecutors.sameThreadExecutor();
ExecutorService listenerExecutor = userthreads;
- checkThresholdsUsingFuturesCompose(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
+ checkThresholdsUsingFuturesTransform(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
} finally {
userthreads.shutdownNow();
}
@@ -165,18 +165,18 @@ public class FuturesComposePerformanceTest {
ExecutorService chainExecutor = MoreExecutors.sameThreadExecutor();
ExecutorService listenerExecutor = MoreExecutors.sameThreadExecutor();
- checkThresholdsUsingFuturesCompose(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
+ checkThresholdsUsingFuturesTransform(expectedMin, expectedMax, expectedOverhead, chainExecutor, listenerExecutor);
} finally {
userthreads.shutdownNow();
}
}
- private void checkThresholdsUsingFuturesCompose(long expectedMin, long expectedMax, long expectedOverhead,
+ private void checkThresholdsUsingFuturesTransform(long expectedMin, long expectedMax, long expectedOverhead,
ExecutorService chainExecutor, final ExecutorService listenerExecutor) {
long start = System.currentTimeMillis();
Map> responses = newHashMap();
for (int i = 0; i < COUNT; i++)
- responses.put(i + "", Futures.compose(Futures.makeListenable(simultateIO(), chainExecutor),
+ responses.put(i + "", Futures.transform(Futures.makeListenable(simultateIO(), chainExecutor),
new Function() {
@Override
@@ -53,23 +53,23 @@ import com.google.common.collect.Sets;
* for handling the listeners.
*
- * This test shows that Futures.compose eagerly issues a get() on the source future. code iterating
+ * This test shows that Futures.transform eagerly issues a get() on the source future. code iterating
* over futures and assigning listeners will take the same amount of time as calling get() on each
* one, if using a within thread executor. This exposes an inefficiency which can make some use